@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 # Mathmaker Lib offers lualatex-printable mathematical objects.
-# Copyright 2006-2017 Nicolas Hainaux <nh.techn@gmail.com>
+# Copyright 2006-2019 Nicolas Hainaux <nh.techn@gmail.com>
 
 # This file is part of Mathmaker Lib.
 
@@ -19,7 +19,6 @@
 # along with Mathmaker Lib; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-import locale
 from math import atan2, degrees
 
 from mathmakerlib import required, config
@@ -575,9 +574,9 @@ class Angle(Drawable, Oriented, HasThickness, Dimensional):
     @property
     def name(self):
         loc = None
-        for l in ['fr', 'en']:
-            if config.language.startswith(l):
-                loc = l
+        for lg in ['fr', 'en']:
+            if config.language.startswith(lg):
+                loc = lg
         if self.naming_mode == 'from_endpoints':
             content = '{}{}{}'.format(self.endpoints[0].name,
                                       self.vertex.name,
@@ -623,11 +622,8 @@ class Angle(Drawable, Oriented, HasThickness, Dimensional):
         # As of now, there is no reliable way to temporarily change the
         # locale to 'C' (or 'en_US'), so here's a little patch that will
         # replace possibly other decimal points by a '.'.
-        theta = str(Bipoint(self.vertex, self.points[0])
-                    .slope.rounded(Number('0.01')).printed)
-        if (locale.localeconv()['decimal_point'] != '.'
-            and locale.localeconv()['decimal_point'] in theta):
-            theta = theta.replace(locale.localeconv()['decimal_point'], '.')
+        theta = Bipoint(self.vertex, self.points[0])\
+            .slope.rounded(Number('0.01')).imprint(dot=True)
         rt = 'cm={{cos({θ}), sin({θ}), -sin({θ}), cos({θ}), ({v})}}' \
             .format(θ=theta, v=self.vertex.name)
         draw_options = tikz_options_list([self.decoration.thickness,
@@ -639,7 +635,7 @@ class Angle(Drawable, Oriented, HasThickness, Dimensional):
         elif winding == 'clockwise':
             rightangle_shape = '({R}, 0) -- ({R}, -{R}) -- (0, -{R})'\
                 .format(R=self.decoration.radius.uiprinted)
-        return '\draw{} {};'.format(draw_options, rightangle_shape)
+        return r'\draw' + '{} {};'.format(draw_options, rightangle_shape)
 
     def tikz_declarations(self):
         """Return the Points declarations."""
@@ -700,7 +696,7 @@ class Angle(Drawable, Oriented, HasThickness, Dimensional):
         decoration = self.tikz_decorations()
         if decoration != '':
             decoration = '\n' + decoration
-        commands = ['\draw{} ({}) -- ({}) -- ({}){};'
+        commands = [r'\draw' + '{} ({}) -- ({}) -- ({}){};'
                     .format(tikz_options_list('draw', self),
                             *[p.name for p in self.points],
                             decoration)
@@ -843,7 +839,7 @@ class AnglesSet(Drawable):
             decoration = α.tikz_decorations()
             if decoration != '':
                 decoration = '\n' + decoration
-            angles_cmd.append('\draw{} ({}) -- ({}) -- ({}){};'
+            angles_cmd.append(r'\draw' + '{} ({}) -- ({}) -- ({}){};'
                               .format(tikz_options_list('draw', α),
                                       *[p.name for p in α.points],
                                       decoration))
